#[non_exhaustive]pub enum BuiltinEnvironmentSpec {
TunerBridge,
CoinFlip,
BiasedRockPaperScissor,
KuhnPoker,
ExtendedTiger,
TicTacToe,
Blackjack,
Platformer,
}Expand description
Built-in non-VM environment choices available to planner runs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TunerBridge
Internal planner environment bridge used by tuner controller execution.
CoinFlip
GameEngine biased coin-flip environment.
BiasedRockPaperScissor
GameEngine biased rock-paper-scissor environment.
KuhnPoker
GameEngine Kuhn poker environment.
ExtendedTiger
GameEngine extended tiger environment.
TicTacToe
GameEngine tic-tac-toe environment.
Blackjack
GameEngine blackjack environment.
Platformer
GameEngine platformer environment.
Implementations
Sourceimpl BuiltinEnvironmentSpec
impl BuiltinEnvironmentSpec
Sourcepub fn canonical_name(&self) -> &'static str
pub fn canonical_name(&self) -> &'static str
Stable canonical name string for this builtin environment.
This is the canonical document/CLI identifier used in serialized specs; it does not change when new builtins are added.