#[non_exhaustive]pub enum SpecDocument {
PlannerRun(PlannerRunSpec),
RateBackend(RateBackend),
CompressionBackend(CompressionBackend),
}Expand description
Universal top-level spec document.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PlannerRun(PlannerRunSpec)
Planner-run configuration document.
RateBackend(RateBackend)
Standalone rate-backend document.
CompressionBackend(CompressionBackend)
Standalone compression-backend document.
Implementations
Sourceimpl SpecDocument
impl SpecDocument
Sourcepub fn to_binary(&self) -> Vec<u8> ⓘ
pub fn to_binary(&self) -> Vec<u8> ⓘ
Encode this document in the versioned binary document envelope.
Sourcepub fn parse_json_value(value: &Value, base_dir: &Path) -> SpecResult<Self>
pub fn parse_json_value(value: &Value, base_dir: &Path) -> SpecResult<Self>
Parse a canonical JSON document from a raw JSON value.
Sourcepub fn parse_json_value_staged(
value: &Value,
base_dir: &Path,
) -> SpecResult<ParsedSpecDocument>
pub fn parse_json_value_staged( value: &Value, base_dir: &Path, ) -> SpecResult<ParsedSpecDocument>
Parse a canonical JSON document and return the parsed-stage wrapper.
Sourcepub fn from_binary(bytes: &[u8], base_dir: &Path) -> SpecResult<Self>
pub fn from_binary(bytes: &[u8], base_dir: &Path) -> SpecResult<Self>
Decode a binary spec document.
Sourcepub fn from_binary_staged(
bytes: &[u8],
base_dir: &Path,
) -> SpecResult<ParsedSpecDocument>
pub fn from_binary_staged( bytes: &[u8], base_dir: &Path, ) -> SpecResult<ParsedSpecDocument>
Decode a binary spec document and return the parsed-stage wrapper.
Sourcepub fn validate_in(
&self,
env: &SpecEnvironment,
) -> SpecResult<ValidatedSpecDocument>
pub fn validate_in( &self, env: &SpecEnvironment, ) -> SpecResult<ValidatedSpecDocument>
Validate this top-level document in the supplied environment.
Sourcepub fn validate(&self) -> SpecResult<ValidatedSpecDocument>
pub fn validate(&self) -> SpecResult<ValidatedSpecDocument>
Validate this top-level document using the default compilation environment.
Sourcepub fn compile_in(
&self,
env: &SpecEnvironment,
) -> SpecResult<CompiledSpecDocument>
pub fn compile_in( &self, env: &SpecEnvironment, ) -> SpecResult<CompiledSpecDocument>
Validate and compile this top-level document in the supplied environment.
Sourcepub fn compile(&self) -> SpecResult<CompiledSpecDocument>
pub fn compile(&self) -> SpecResult<CompiledSpecDocument>
Validate and compile this top-level document using the default environment.