pub fn load_mixture_spec_with_depth(
path: &str,
depth: usize,
) -> SpecResult<MixtureSpec>Expand description
Load a mixture spec from disk with an explicit remaining nesting budget.
pub fn load_mixture_spec_with_depth(
path: &str,
depth: usize,
) -> SpecResult<MixtureSpec>Load a mixture spec from disk with an explicit remaining nesting budget.