pub fn resolve_enabled_rate_backend_name(
input: &str,
) -> SpecResult<&'static str>Expand description
Resolve a rate backend alias and require that it is enabled in the current build.
pub fn resolve_enabled_rate_backend_name(
input: &str,
) -> SpecResult<&'static str>Resolve a rate backend alias and require that it is enabled in the current build.