#[non_exhaustive]pub struct ParsedSpecDocument { /* private fields */ }Expand description
Parsed top-level spec document paired with its parse base directory.
This is the first stage of the canonical pipeline: parse -> validate -> compile.
Implementations
Sourceimpl ParsedSpecDocument
impl ParsedSpecDocument
Sourcepub fn document(&self) -> &SpecDocument
pub fn document(&self) -> &SpecDocument
Parsed document before validation.
Sourcepub fn into_document(self) -> SpecDocument
pub fn into_document(self) -> SpecDocument
Consume this stage wrapper and return the parsed document.
Sourcepub fn validate(self) -> SpecResult<ValidatedSpecDocument>
pub fn validate(self) -> SpecResult<ValidatedSpecDocument>
Validate this parsed document in the captured parse environment.
Sourcepub fn compile(self) -> SpecResult<CompiledSpecDocument>
pub fn compile(self) -> SpecResult<CompiledSpecDocument>
Validate and compile this parsed document in the captured parse environment.