#[non_exhaustive]pub struct RateBackendShorthandOptions {Show 13 fields
pub base_dir: PathBuf,
pub ctw_depth: usize,
pub fac_ctw_base_depth: usize,
pub fac_ctw_num_percept_bits: usize,
pub fac_ctw_encoding_bits: usize,
pub fac_ctw_msb_first: Option<bool>,
pub ppmd_order: usize,
pub ppmd_memory_mb: usize,
pub sequitur_context_bytes: usize,
pub zpaq_method: String,
pub default_mamba_model_path: Option<String>,
pub default_rwkv_model_path: Option<String>,
pub particle_default_if_missing_method: bool,
}Expand description
Defaults for shorthand backend parsing such as CLI --rate-backend ... --method ....
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.base_dir: PathBufBase directory used to resolve relative spec/model paths.
ctw_depth: usizeDefault CTW depth when no numeric method is supplied.
fac_ctw_base_depth: usizeDefault FAC-CTW base depth when no numeric method is supplied.
fac_ctw_num_percept_bits: usizeDefault FAC-CTW percept width.
fac_ctw_encoding_bits: usizeDefault FAC-CTW symbol encoding width.
fac_ctw_msb_first: Option<bool>Optional FAC-CTW MSB-first override for shorthand CLI parsing.
None defers to compile-time default (encoding_bits == 8 → MSB-first).
ppmd_order: usizeDefault PPMD order.
ppmd_memory_mb: usizeDefault PPMD memory budget in MiB.
sequitur_context_bytes: usizeDefault Sequitur context window.
zpaq_method: StringDefault ZPAQ rate method.
default_mamba_model_path: Option<String>Optional default Mamba model path when no method is supplied.
default_rwkv_model_path: Option<String>Optional default RWKV7 model path when no method is supplied.
particle_default_if_missing_method: boolWhether particle without a method should build ParticleSpec::default().